@@ -1,24 +1,31 @@
 gen.variogram <-
-function(x, y, lag = mean(x)/sqrt(nrow(x)), tol=lag/2, lmax = NA,
+function(x, y, lag = quantile(as.matrix(x), 0.05), tol=lag/2, lmax = NA,
          bootstraps = 999, verbose = FALSE) {
 
-    ## Check x class status and attempt coercion to matrix
-    if (!(class(x) == "matrix")) {
-        x <- as.matrix(x)
-    }
+    ## Check x class status and attempt coercion to dist
+    if (!(class(x) == "dist"))
+            x <- as.dist(x)
 
     ## Check if there are multiple genetic distances and
-    ## attempt coercion to matrix
-    multi <- FALSE    
+    ## attempt coercion to dist
+    multi <- FALSE
     if (class(y) == "list") {
         multi <- TRUE
         for (i in 1:length(y)) {
-            y[[i]] <- as.matrix(y[[i]])
-        }
+            if (!(class(y[[i]]) == "dist"))
+                y[[i]] <- as.dist(y[[i]])
+
+            if (!all(dim(y[[i]]) == dim(x)))
+                stop("Dimensions of x and y do not match.")
+       }
     } else {
-        y <- as.matrix(y)
+        if (!(class(y) == "dist"))
+            y <- as.dist(y)
+
+        if (!all(dim(y) == dim(x)))
+            stop("Dimensions of x and y do not match.")
     }
-            
+
     if (multi) {
         gv <- .gen.variogram.multi(x, y, lag = lag, tol = tol,
                                   lmax = lmax,
@@ -33,9 +40,7 @@ function(x, y, lag = mean(x)/sqrt(nrow(x)), tol=lag/2, lmax = NA,
     if (sum(is.na(gv$gamma)) > 0) {
         warning("The variogram contains NAs.",
                 "Consider adjusting the lag.")
-    }    
+    }
 
     gv
 }
-
-
